Class: Aws::Scheduler::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Scheduler::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-scheduler/client.rb,
sig/client.rbs
Overview
An API client for Scheduler. To construct a client, you need to configure a :region and :credentials.
client = Aws::Scheduler::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateScheduleGroupResponseSuccess, _CreateScheduleResponseSuccess, _DeleteScheduleGroupResponseSuccess, _DeleteScheduleResponseSuccess, _GetScheduleGroupResponseSuccess, _GetScheduleResponseSuccess, _ListScheduleGroupsResponseSuccess, _ListSchedulesResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateScheduleResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleOutput
Creates the specified schedule.
-
#create_schedule_group(params = {}) ⇒ Types::CreateScheduleGroupOutput
Creates the specified schedule group.
-
#delete_schedule(params = {}) ⇒ Struct
Deletes the specified schedule.
-
#delete_schedule_group(params = {}) ⇒ Struct
Deletes the specified schedule group.
-
#get_schedule(params = {}) ⇒ Types::GetScheduleOutput
Retrieves the specified schedule.
-
#get_schedule_group(params = {}) ⇒ Types::GetScheduleGroupOutput
Retrieves the specified schedule group.
-
#list_schedule_groups(params = {}) ⇒ Types::ListScheduleGroupsOutput
Returns a paginated list of your schedule groups.
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesOutput
Returns a paginated list of your EventBridge Scheduler schedules.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the Scheduler resource.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge Scheduler resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge Scheduler schedule group.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleOutput
Updates the specified schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-scheduler/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1379 1380 1381 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1379 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1382 1383 1384 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1382 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1352 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Scheduler') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-scheduler' context[:gem_version] = '1.49.0' Seahorse::Client::Request.new(handlers, context) end |
#create_schedule(params = {}) ⇒ Types::CreateScheduleOutput
Creates the specified schedule.
86 |
# File 'sig/client.rbs', line 86
def create_schedule: (
|
#create_schedule_group(params = {}) ⇒ Types::CreateScheduleGroupOutput
Creates the specified schedule group.
111 |
# File 'sig/client.rbs', line 111
def create_schedule_group: (
|
#delete_schedule(params = {}) ⇒ Struct
Deletes the specified schedule.
127 |
# File 'sig/client.rbs', line 127
def delete_schedule: (
|
#delete_schedule_group(params = {}) ⇒ Struct
Deletes the specified schedule group. Deleting a schedule group
results in EventBridge Scheduler deleting all schedules associated
with the group. When you delete a group, it remains in a DELETING
state until all of its associated schedules are deleted. Schedules
associated with the group that are set to run while the schedule group
is in the process of being deleted might continue to invoke their
targets until the schedule group and its associated schedules are
deleted.
138 |
# File 'sig/client.rbs', line 138
def delete_schedule_group: (
|
#get_schedule(params = {}) ⇒ Types::GetScheduleOutput
Retrieves the specified schedule.
163 |
# File 'sig/client.rbs', line 163
def get_schedule: (
|
#get_schedule_group(params = {}) ⇒ Types::GetScheduleGroupOutput
Retrieves the specified schedule group.
178 |
# File 'sig/client.rbs', line 178
def get_schedule_group: (
|
#list_schedule_groups(params = {}) ⇒ Types::ListScheduleGroupsOutput
Returns a paginated list of your schedule groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
189 |
# File 'sig/client.rbs', line 189
def list_schedule_groups: (
|
#list_schedules(params = {}) ⇒ Types::ListSchedulesOutput
Returns a paginated list of your EventBridge Scheduler schedules.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
202 |
# File 'sig/client.rbs', line 202
def list_schedules: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the Scheduler resource.
216 |
# File 'sig/client.rbs', line 216
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge Scheduler resource. You can only assign tags to schedule groups.
225 |
# File 'sig/client.rbs', line 225
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge Scheduler schedule group.
240 |
# File 'sig/client.rbs', line 240
def untag_resource: (
|
#update_schedule(params = {}) ⇒ Types::UpdateScheduleOutput
Updates the specified schedule. When you call UpdateSchedule,
EventBridge Scheduler uses all values, including empty values,
specified in the request and overrides the existing schedule. This is
by design. This means that if you do not set an optional field in your
request, that field will be set to its system-default value after the
update.
Before calling this operation, we recommend that you call the
GetSchedule API operation and make a note of all optional parameters
for your UpdateSchedule call.
251 |
# File 'sig/client.rbs', line 251
def update_schedule: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1372 1373 1374 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1372 def waiter_names [] end |