Class: Aws::Scheduler::Types::RetryPolicy

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-scheduler/types.rb

Overview

A RetryPolicy object that includes information about the retry policy settings, including the maximum age of an event, and the maximum number of times EventBridge Scheduler will try to deliver the event to a target.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maximum_event_age_in_seconds ⇒ Integer

The maximum amount of time, in seconds, to continue to make retry attempts.

Returns:



955
956
957
958
959
960
# File 'lib/aws-sdk-scheduler/types.rb', line 955

class RetryPolicy < Struct.new(
  :maximum_event_age_in_seconds,
  :maximum_retry_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_retry_attempts ⇒ Integer

The maximum number of retry attempts to make before the request fails. Retry attempts with exponential backoff continue until either the maximum number of attempts is made or until the duration of the MaximumEventAgeInSeconds is reached.

Returns:



955
956
957
958
959
960
# File 'lib/aws-sdk-scheduler/types.rb', line 955

class RetryPolicy < Struct.new(
  :maximum_event_age_in_seconds,
  :maximum_retry_attempts)
  SENSITIVE = []
  include Aws::Structure
end