Class: Aws::Scheduler::Types::SageMakerPipelineParameter

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-scheduler/types.rb

Overview

The name and value pair of a parameter to use to start execution of a SageMaker Model Building Pipeline.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ String

Name of parameter to start execution of a SageMaker Model Building Pipeline.

Returns:



977
978
979
980
981
982
# File 'lib/aws-sdk-scheduler/types.rb', line 977

class SageMakerPipelineParameter < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ String

Value of parameter to start execution of a SageMaker Model Building Pipeline.

Returns:



977
978
979
980
981
982
# File 'lib/aws-sdk-scheduler/types.rb', line 977

class SageMakerPipelineParameter < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end