Class: Aws::Scheduler::Types::ScheduleSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-scheduler/types.rb

Overview

The details of a schedule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the schedule.

Returns:

  • (String)


1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/aws-sdk-scheduler/types.rb', line 1070

class ScheduleSummary < Struct.new(
  :arn,
  :creation_date,
  :group_name,
  :last_modification_date,
  :name,
  :state,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date ⇒ Time

The time at which the schedule was created.

Returns:

  • (Time)


1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/aws-sdk-scheduler/types.rb', line 1070

class ScheduleSummary < Struct.new(
  :arn,
  :creation_date,
  :group_name,
  :last_modification_date,
  :name,
  :state,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#group_name ⇒ String

The name of the schedule group associated with this schedule.

Returns:

  • (String)


1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/aws-sdk-scheduler/types.rb', line 1070

class ScheduleSummary < Struct.new(
  :arn,
  :creation_date,
  :group_name,
  :last_modification_date,
  :name,
  :state,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_date ⇒ Time

The time at which the schedule was last modified.

Returns:

  • (Time)


1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/aws-sdk-scheduler/types.rb', line 1070

class ScheduleSummary < Struct.new(
  :arn,
  :creation_date,
  :group_name,
  :last_modification_date,
  :name,
  :state,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the schedule.

Returns:

  • (String)


1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/aws-sdk-scheduler/types.rb', line 1070

class ScheduleSummary < Struct.new(
  :arn,
  :creation_date,
  :group_name,
  :last_modification_date,
  :name,
  :state,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

Specifies whether the schedule is enabled or disabled.

Returns:

  • (String)


1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/aws-sdk-scheduler/types.rb', line 1070

class ScheduleSummary < Struct.new(
  :arn,
  :creation_date,
  :group_name,
  :last_modification_date,
  :name,
  :state,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#target ⇒ Types::TargetSummary

The schedule's target details.



1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/aws-sdk-scheduler/types.rb', line 1070

class ScheduleSummary < Struct.new(
  :arn,
  :creation_date,
  :group_name,
  :last_modification_date,
  :name,
  :state,
  :target)
  SENSITIVE = []
  include Aws::Structure
end