Class: Aws::Scheduler::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Scheduler::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-scheduler/client.rb
Overview
An API client for Scheduler. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Scheduler::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_schedule(params = {}) ⇒ Types::CreateScheduleOutput
Creates the specified schedule.
-
#create_schedule_group(params = {}) ⇒ Types::CreateScheduleGroupOutput
Creates the specified schedule group.
-
#delete_schedule(params = {}) ⇒ Struct
Deletes the specified schedule.
-
#delete_schedule_group(params = {}) ⇒ Struct
Deletes the specified schedule group.
-
#get_schedule(params = {}) ⇒ Types::GetScheduleOutput
Retrieves the specified schedule.
-
#get_schedule_group(params = {}) ⇒ Types::GetScheduleGroupOutput
Retrieves the specified schedule group.
-
#list_schedule_groups(params = {}) ⇒ Types::ListScheduleGroupsOutput
Returns a paginated list of your schedule groups.
-
#list_schedules(params = {}) ⇒ Types::ListSchedulesOutput
Returns a paginated list of your EventBridge Scheduler schedules.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the Scheduler resource.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge Scheduler resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge Scheduler schedule group.
-
#update_schedule(params = {}) ⇒ Types::UpdateScheduleOutput
Updates the specified schedule.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-scheduler/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1379 1380 1381 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1379 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1382 1383 1384 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1382 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1352 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Scheduler') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-scheduler' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#create_schedule(params = {}) ⇒ Types::CreateScheduleOutput
Creates the specified schedule.
668 669 670 671 |
# File 'lib/aws-sdk-scheduler/client.rb', line 668 def create_schedule(params = {}, = {}) req = build_request(:create_schedule, params) req.send_request() end |
#create_schedule_group(params = {}) ⇒ Types::CreateScheduleGroupOutput
Creates the specified schedule group.
715 716 717 718 |
# File 'lib/aws-sdk-scheduler/client.rb', line 715 def create_schedule_group(params = {}, = {}) req = build_request(:create_schedule_group, params) req.send_request() end |
#delete_schedule(params = {}) ⇒ Struct
Deletes the specified schedule.
752 753 754 755 |
# File 'lib/aws-sdk-scheduler/client.rb', line 752 def delete_schedule(params = {}, = {}) req = build_request(:delete_schedule, params) req.send_request() end |
#delete_schedule_group(params = {}) ⇒ Struct
Deletes the specified schedule group. Deleting a schedule group results in EventBridge Scheduler deleting all schedules associated with the group. When you delete a group, it remains in a ‘DELETING` state until all of its associated schedules are deleted. Schedules associated with the group that are set to run while the schedule group is in the process of being deleted might continue to invoke their targets until the schedule group and its associated schedules are deleted.
<note markdown=“1”> This operation is eventually consistent.
</note>
795 796 797 798 |
# File 'lib/aws-sdk-scheduler/client.rb', line 795 def delete_schedule_group(params = {}, = {}) req = build_request(:delete_schedule_group, params) req.send_request() end |
#get_schedule(params = {}) ⇒ Types::GetScheduleOutput
Retrieves the specified schedule.
897 898 899 900 |
# File 'lib/aws-sdk-scheduler/client.rb', line 897 def get_schedule(params = {}, = {}) req = build_request(:get_schedule, params) req.send_request() end |
#get_schedule_group(params = {}) ⇒ Types::GetScheduleGroupOutput
Retrieves the specified schedule group.
933 934 935 936 |
# File 'lib/aws-sdk-scheduler/client.rb', line 933 def get_schedule_group(params = {}, = {}) req = build_request(:get_schedule_group, params) req.send_request() end |
#list_schedule_groups(params = {}) ⇒ Types::ListScheduleGroupsOutput
Returns a paginated list of your schedule groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
982 983 984 985 |
# File 'lib/aws-sdk-scheduler/client.rb', line 982 def list_schedule_groups(params = {}, = {}) req = build_request(:list_schedule_groups, params) req.send_request() end |
#list_schedules(params = {}) ⇒ Types::ListSchedulesOutput
Returns a paginated list of your EventBridge Scheduler schedules.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1042 1043 1044 1045 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1042 def list_schedules(params = {}, = {}) req = build_request(:list_schedules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags associated with the Scheduler resource.
1073 1074 1075 1076 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1073 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified EventBridge Scheduler resource. You can only assign tags to schedule groups.
1107 1108 1109 1110 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1107 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified EventBridge Scheduler schedule group.
1135 1136 1137 1138 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1135 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_schedule(params = {}) ⇒ Types::UpdateScheduleOutput
Updates the specified schedule. When you call ‘UpdateSchedule`, EventBridge Scheduler uses all values, including empty values, specified in the request and overrides the existing schedule. This is by design. This means that if you do not set an optional field in your request, that field will be set to its system-default value after the update.
Before calling this operation, we recommend that you call the ‘GetSchedule` API operation and make a note of all optional parameters for your `UpdateSchedule` call.
1343 1344 1345 1346 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1343 def update_schedule(params = {}, = {}) req = build_request(:update_schedule, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1372 1373 1374 |
# File 'lib/aws-sdk-scheduler/client.rb', line 1372 def waiter_names [] end |